@@ -89,10 +89,11 @@ LATN_TO_HIRA = {
     'rya': 'りゃ', 'ryu': 'りゅ', 'ryo': 'りょ',
 
     'che': 'ちぇ', 'fa': 'ふぁ', 'vu': 'ゔ', 'fi': 'ふぃ', 'we': 'うぇ',
-    'fo': 'ふぉ', 'fe': 'ふぇ', 'wi': 'うぃ', 'je': 'じぇ',
+    'fo': 'ふぉ', 'fe': 'ふぇ', 'wi': 'うぃ', 'je': 'じぇ', 'fyu': 'ふゅ',
+    'vi': 'ゔぃ',
 
     '-': 'ー', ':': 'ー',
-    'n': 'ん', 'm': 'ん', "n'": 'ん',
+    'n': 'ん', 'm': 'ん', "n'": 'ん', 'f': 'っ',
     'k': 'っ', 's': 'っ', 't': 'っ', 'h': 'っ', 'r': 'っ',
     'g': 'っ', 'z': 'っ', 'd': 'っ', 'b': 'っ', 'p': 'っ',
     'qi': '々', '・': '',
